@@ -16,20 +16,13 @@
 # You should have received a copy of the GNU General Public License
 # along with nrun.  If not, see <http://www.gnu.org/licenses/>.
 #
-# Program: Worker.pm
-# Author:  Timo Benk <benk@b1-systems.de>
-# Date:    Wed May 8 13:46:36 2013 +0200
-# Ident:   31a16b3e65edd6e679b461c0e27ea92a8b373c24
+# Program: <FILE>
+# Author:  <AUTHORNAME> <<AUTHOREMAIL>>
+# Date:    <COMMITTERDATE>
+# Ident:   <COMMITHASH>
 # Branch:  <REFNAMES>
 #
-# Changelog:--reverse --grep '^tags.*relevant':-1:%an : %ai : %s
-# 
-# Timo Benk : 2013-04-28 17:27:31 +0200 : initial checkin
-# Timo Benk : 2013-04-29 18:53:21 +0200 : introducing ncopy
-# Timo Benk : 2013-05-03 13:52:25 +0200 : no output was returned on timeout
-# Timo Benk : 2013-05-03 19:16:11 +0200 : no output was returned on SIGINT
-# Timo Benk : 2013-05-08 10:05:39 +0200 : better signal handling implemented
-# Timo Benk : 2013-05-08 13:46:36 +0200 : skip empty output when signaled USR1/USR2
+# <CHANGELOG:--reverse --grep '^tags.*relevant':-1:%an : %ai : %s>
 #
 
 package NRun::Worker;
@@ -40,8 +33,7 @@ use warnings;
 use File::Basename;
 use NRun::Semaphore;
 
-my $SEMAPHORE = NRun::Semaphore->new({key => int(rand(100000))});
-
+my $semaphore;
 my $workers = {};
 
 ###
@@ -60,12 +52,16 @@ sub workers {
 }
 
 ###
-# dynamically load all available login module
+# dynamically load all available login modules
 #
 # $_cfg - option hash given to the submodules on creation
-sub load_modules {
+# $_sem - semaphore object 
+sub init {
 
     my $_cfg = shift;
+    my $_sem = shift;
+
+    $semaphore = $_sem;
 
     my $basedir = dirname($INC{"NRun/Worker.pm"}) . "/Workers";
 
@@ -102,15 +98,15 @@ sub _ {
 
     local $SIG{USR1} = sub {
 
-        $SEMAPHORE->lock();
+        $semaphore->lock();
         print STDERR "[$$]: ($pid) $_cmd\n";
         print STDERR "[$$]: " . join("[$$]: ", @out) if (scalar(@out));
-        $SEMAPHORE->unlock();
+        $semaphore->unlock();
     };
 
     local $SIG{USR2} = sub {
 
-        $SEMAPHORE->lock();
+        $semaphore->lock();
 
         if (not open(LOG, ">>trace.txt")) {
 
@@ -123,7 +119,7 @@ sub _ {
 
         close(LOG);
 
-        $SEMAPHORE->unlock();
+        $semaphore->unlock();
     };
 
     local $SIG{INT} = sub {
@@ -157,12 +153,16 @@ sub _ {
     return ($? >> 8, join("", @out));
 }
 
+###
+# return this modules mode
 sub mode {
 
     my $_self = shift;
     return $_self->{MODINFO}->{MODE};
 }
 
+###
+# return this modules description
 sub desc {
 
     my $_self = shift;
